Learn R Programming

Bivariate.Pareto (version 1.0.3)

Frank.Pareto: Generate samples from the Frank copula with the Pareto margins

Description

Generate samples from the Frank copula with the Pareto margins.

Usage

Frank.Pareto(n, Theta, Alpha1, Alpha2, Gamma1, Gamma2)

Arguments

n

Sample size.

Theta

Copula parameter \(\theta\).

Alpha1

Positive scale parameter \(\alpha_{1}\) for the Pareto margin.

Alpha2

Positive scale parameter \(\alpha_{2}\) for the Pareto margin.

Gamma1

Positive shape parameter \(\gamma_{1}\) for the Pareto margin.

Gamma2

Positive shape parameter \(\gamma_{2}\) for the Pareto margin.

Value

X

X is asscoiated with the parameters Alpha1 and Gamma1.

Y

Y is asscoiated with the parameters Alpha2 and Gamma2.

References

Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.

Examples

Run this code
# NOT RUN {
library(Bivariate.Pareto)
Frank.Pareto(5,5,1,1,1,1)
# }

Run the code above in your browser using DataLab