Learn R Programming

Bivariate.Pareto (version 1.0.3)

SN.Pareto: Generate samples from the SNBP distribution

Description

Generate samples from the Sankaran and Nair bivairate Pareto (SNBP) distribution (Sankaran and Nair, 1993).

Usage

SN.Pareto(n, Alpha0, Alpha1, Alpha2, Gamma)

Arguments

n

Sample size.

Alpha0

Copula parameter \(\alpha_{0}\) with restricted range.

Alpha1

Positive scale parameter \(\alpha_{1}\) for the Pareto margin.

Alpha2

Positive scale parameter \(\alpha_{2}\) for the Pareto margin.

Gamma

Common positive shape parameter \(\gamma\) for the Pareto margins.

Value

X

X is asscoiated with the parameters Alpha1 and Gamma.

Y

Y is asscoiated with the parameters Alpha2 and Gamma.

Details

The admissible range of Alpha0 (\(\alpha_{0}\)) is \(0 \leq \alpha_{0} \leq (\gamma+1) \alpha_{1} \alpha_{2}.\)

References

Sankaran PG, Nair NU (1993), A bivariate Pareto model and its applications to reliability, Naval Research Logistics, 40(7): 1013-1020.

Shih J-H, Lee W, Sun L-H, Emura T (2019), Fitting competing risks data to bivariate Pareto models, Communications in Statistics - Theory and Methods, 48:1193-1220.

Examples

Run this code
# NOT RUN {
library(Bivariate.Pareto)
SN.Pareto(5,2,1,1,1)
# }

Run the code above in your browser using DataLab